==> cscec5b-dataexchange-impl-3.0.0-20201104.113508-19-sources.jar: com/ejianc/business/dataexchange/service/impl/CorpUserService.java <==
package com.ejianc.business.dataexchange.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ejianc.business.dataexchange.mapper.CorpUserMapper;
import com.ejianc.business.dataexchange.service.ICorpUserService;
import com.ejianc.business.dataexchange.vo.CorpUser;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * <p>
 * 用户组织权限 服务实现类
 * </p>
 *
 * @author Brin
 * @since 2020-11-04 10:16:15
 */
@Service("corpUserService")
public class CorpUserService extends ServiceImpl<CorpUserMapper, CorpUser> implements ICorpUserService {

    @Override
    public List<CorpUser> queryNCCorpUsersByTs(String ts) {
        List<CorpUser> cus = baseMapper.queryNCCorpUsersByTs(ts);
        return cus;
        /*
         *
         * NC中取消用户权限分配，用的是物理删除，以下代码失效...

        List<CorpUser> retlist = null;
        if(!cus.isEmpty()) {
            retlist = new ArrayList<CorpUser>();

            Map<String,List<CorpUser>> corpuserListMap =
                    cus.stream().collect(Collectors.groupingBy(CorpUser::getPkcorpPkuser));
            Integer dr = 0;
            List<CorpUser> finalRetlist = retlist;
            corpuserListMap.forEach((key, value) -> {
               //String pkcorppkuser = key;
               //如果list中只有一个，无论dr=0 或 dr = 1 直接加入返回列表； 如果dr=0 \dr=1都存在，则添加dr=0的那个到返回列表。
                if(value != null && !value.isEmpty()) {
                    if(value.size() == 1) {
                        finalRetlist.addAll(value);
                    } else {
                        finalRetlist.addAll(value.stream().filter(corpUser -> corpUser.getDr()==0).collect(Collectors.toList()));
                    }
                }

            });

        }
       // System.out.println("total_"+retlist.size());
        return retlist;*/

    }
}

==> cscec5b-dataexchange-impl-3.0.0-20201118.051117-32-sources.jar: com/ejianc/business/dataexchange/service/impl/CorpUserService.java <==
package com.ejianc.business.dataexchange.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ejianc.business.dataexchange.mapper.CorpUserMapper;
import com.ejianc.business.dataexchange.service.ICorpUserService;
import com.ejianc.business.dataexchange.vo.CorpUser;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * <p>
 * 用户组织权限 服务实现类
 * </p>
 *
 * @author Brin
 * @since 2020-11-04 10:16:15
 */
@Service("corpUserService")
public class CorpUserService extends ServiceImpl<CorpUserMapper, CorpUser> implements ICorpUserService {

    @Override
    public List<CorpUser> queryNCCorpUsersByTs(String ts) {
        List<CorpUser> cus = baseMapper.queryNCCorpUsersByTs(ts);
        return cus;
        /*
         *
         * NC中取消用户权限分配，用的是物理删除，以下代码失效...

        List<CorpUser> retlist = null;
        if(!cus.isEmpty()) {
            retlist = new ArrayList<CorpUser>();

            Map<String,List<CorpUser>> corpuserListMap =
                    cus.stream().collect(Collectors.groupingBy(CorpUser::getPkcorpPkuser));
            Integer dr = 0;
            List<CorpUser> finalRetlist = retlist;
            corpuserListMap.forEach((key, value) -> {
               //String pkcorppkuser = key;
               //如果list中只有一个，无论dr=0 或 dr = 1 直接加入返回列表； 如果dr=0 \dr=1都存在，则添加dr=0的那个到返回列表。
                if(value != null && !value.isEmpty()) {
                    if(value.size() == 1) {
                        finalRetlist.addAll(value);
                    } else {
                        finalRetlist.addAll(value.stream().filter(corpUser -> corpUser.getDr()==0).collect(Collectors.toList()));
                    }
                }

            });

        }
       // System.out.println("total_"+retlist.size());
        return retlist;*/

    }

    @Override
    public List<CorpUser> queryNCCorpUsersByQj(String beginTime, String endTime) {
        return baseMapper.queryNCCorpUsersByQj(beginTime, endTime);
    }
}
